<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_CL">
<context>
    <name>Converter</name>
    <message>
        <location filename="../src/converter.cpp" line="87"/>
        <location filename="../src/converter.cpp" line="94"/>
        <location filename="../src/converter.cpp" line="101"/>
        <source>Error: %1</source>
        <translation>Error: %1</translation>
    </message>
</context>
<context>
    <name>DialogConversionStatus</name>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="14"/>
        <source>Status...</source>
        <translation>Estado...</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="20"/>
        <source>Conversion Status</source>
        <translation>Estado de la conversión</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="46"/>
        <source>Image:</source>
        <translation>Imagen:</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="51"/>
        <source>Status:</source>
        <translation>Estado:</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="70"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Total:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Total:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="81"/>
        <location filename="../ui/dialogconversionstatus.ui" line="116"/>
        <location filename="../ui/dialogconversionstatus.ui" line="151"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="105"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Converted:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Convertidas:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="140"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Errors:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Errores:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="191"/>
        <source>Open destination </source>
        <translation>Abrir destino </translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="211"/>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="218"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../src/dialogconversionstatus.cpp" line="41"/>
        <source>Open all the destination folders</source>
        <translation>Abrir todas las carpetas de destino</translation>
    </message>
    <message>
        <location filename="../src/dialogconversionstatus.cpp" line="75"/>
        <source>Converted</source>
        <translation>Convertidas</translation>
    </message>
</context>
<context>
    <name>DialogInfo</name>
    <message>
        <location filename="../ui/dialoginfo.ui" line="20"/>
        <source>About Converseen...</source>
        <translation>Acerca de Converseen...</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="86"/>
        <source>Informations</source>
        <translation>Información</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="108"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Translators:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Traductores:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="44"/>
        <location filename="../ui/dialoginfo.ui" line="67"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="143"/>
        <source>&lt;strong&gt;Hungarian translation: &lt;/strong&gt;Charles Barcza - &lt;a href=&quot;mailto:kbarcza@blackpanther.hu&quot;&gt;kbarcza@blackpanther.hu&lt;/a&gt;</source>
        <translation>&lt;strong&gt;Traducción al húngaro: &lt;/strong&gt;Charles Barcza - &lt;a href=&quot;mailto:kbarcza@blackpanther.hu&quot;&gt;kbarcza@blackpanther.hu&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="150"/>
        <source>&lt;strong&gt;Czech translation: &lt;/strong&gt;Pavel Fric - &lt;a href=&quot;mailto:pavelfric@seznam.cz&quot;&gt;pavelfric@seznam.cz&lt;/a&gt;</source>
        <translation>&lt;strong&gt;Traducción al checo: &lt;/strong&gt;Pavel Fric - &lt;a href=&quot;mailto:pavelfric@seznam.cz&quot;&gt;pavelfric@seznam.cz&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="164"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Brazilian Portuguese Translation: &lt;/span&gt;Paulo Guzmán - &lt;a href=&quot;mailto:white.hat@msn.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;white.hat@msn.com&lt;/span&gt;&lt;/a&gt; -&lt;span style=&quot; font-weight:600;&quot;/&gt;Márcio Moraes - &lt;a href=&quot;mailto:marciopanto@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;marciopanto@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="174"/>
        <source>&lt;strong&gt;German Translation: &lt;/strong&gt;Marco Nickolai - &lt;a href=&quot;mailto:nickolai@iad.tu-darmstadt.de&quot;&gt;nickolai@iad.tu-darmstadt.de&lt;/a&gt;</source>
        <translation>&lt;strong&gt;Traducción al alemán: &lt;/strong&gt;Marco Nickolai - &lt;a href=&quot;mailto:nickolai@iad.tu-darmstadt.de&quot;&gt;nickolai@iad.tu-darmstadt.de&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&lt;strong&gt;Spanish (Chile) Translation: &lt;/strong&gt;Nelson Álvarez Sáez - &lt;a href=&quot;mailto:alvareznelson@gmail.com&quot;&gt;alvareznelson@gmail.com&lt;/a&gt;
</source>
        <translation type="vanished">&lt;strong&gt;Traducción al español: &lt;/strong&gt;Nelson Álvarez Sáez - &lt;a href=&quot;mailto:alvareznelson@gmail.com&quot;&gt;alvareznelson@gmail.com&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&lt;strong&gt;Turkish Translation: &lt;/strong&gt;Zeugma - &lt;a href=&quot;mailto:sunder67@hotmail.com&quot;&gt;sunder67@hotmail.com&lt;/a&gt;
</source>
        <translation type="vanished">&lt;strong&gt;Traducción al turco: &lt;/strong&gt;Zeugma - &lt;a href=&quot;mailto:sunder67@hotmail.com&quot;&gt;sunder67@hotmail.com&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&lt;strong&gt;Russian Translation: &lt;/strong&gt;Stasik Savorovsky - &lt;a href=&quot;mailto:stas_stv@mail.ru&quot;&gt;stas_stv@mail.ru&lt;/a&gt;</source>
        <translation type="vanished">&lt;strong&gt;Traducción al ruso: &lt;/strong&gt;Stasik Savorovsky - &lt;a href=&quot;mailto:stas_stv@mail.ru&quot;&gt;stas_stv@mail.ru&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="208"/>
        <source>&lt;strong&gt;Polish Translation: &lt;/strong&gt;Michał Olber from OSWorld.pl - &lt;a href=&quot;mailto:redakcja@osworld.pl&quot;&gt;redakcja@osworld.pl&lt;/a&gt;</source>
        <translation>&lt;strong&gt;Traducción al polaco: &lt;/strong&gt;Michał Olber, de OSWorld.pl - &lt;a href=&quot;mailto:redakcja@osworld.pl&quot;&gt;redakcja@osworld.pl&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="218"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Japanese translation:&lt;/span&gt; Xenolith0 - &lt;a href=&quot;mailto:xenolith0bytetestcomgreen@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;xenolith0bytetestcomgreen@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="225"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Danish translation: &lt;/span&gt;Martin Eilsoe - &lt;a href=&quot;mailto:martin.eilsoe@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;martin.eilsoe@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="232"/>
        <source>&lt;strong&gt;Ukrainian translation: &lt;/strong&gt;AleXKaN - &lt;a href=&quot;mailto:aws2@india.com&quot;&gt;aws2@india.com&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="246"/>
        <source>&lt;strong&gt;Simplified Chinese translation: &lt;/strong&gt;myd7349 - &lt;a href=&quot;mailto:myd7349@gmail.com&quot;&gt;myd7349@gmail.com&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="53"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt;&quot;&gt;Converseen is an image batch conversion tool. You can resize and convert images in more than 100 different formats.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt;&quot;&gt;Converseen convierte tus imágenes por lotes. Puedes redimensionar y convertir imágenes en más de 100 formatos distintos.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="92"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt; font-weight:600;&quot;&gt;Author: &lt;/span&gt;&lt;span style=&quot; font-size:10pt;&quot;&gt;Francesco Mondello (Faster) - &lt;/span&gt;&lt;a href=&quot;https://fasterland.net/&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;fasterland.net&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt; font-weight:600;&quot;&gt;Email: &lt;/span&gt;&lt;a href=&quot;faster3ck@gmail.com&quot;&gt;&lt;span style=&quot; font-size:10pt; text-decoration: underline; &quot;&gt;faster3ck@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt; font-weight:600;&quot;&gt;Project Website: &lt;/span&gt;&lt;a href=&quot;https://converseen.fasterland.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;converseen.fasterland.net&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="157"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;French Translation: &lt;/span&gt;Adrien DAUGABEL - &lt;a href=&quot;mailto:adrien.d@mageialinux-online.org&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;adrien.d@mageialinux-online.org - &lt;/span&gt;&lt;/a&gt;David GEIGER &lt;a href=&quot;mailto:david.david@mageialinux-online.org&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;david.david@mageialinux-online.org&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="181"/>
        <source>&lt;strong&gt;Spanish (Chile) Translation: &lt;/strong&gt;Nelson Álvarez Sáez - &lt;a href=&quot;mailto:alvareznelson@gmail.com&quot;&gt;alvareznelson@gmail.com&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="188"/>
        <source>&lt;strong&gt;Turkish Translation: &lt;/strong&gt;Zeugma - &lt;a href=&quot;mailto:sunder67@hotmail.com&quot;&gt;sunder67@hotmail.com&lt;/a&gt; - Sabri Ünal - &lt;a href=&quot;mailto:libreajans@gmail.com&quot;&gt;libreajans@gmail.com&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="198"/>
        <source>&lt;strong&gt;Russian Translation: &lt;/strong&gt;Stasik Savorovsky - &lt;a href=&quot;mailto:stas_stv@mail.ru&quot;&gt;stas_stv@mail.ru&lt;/a&gt;, Kyrill Detinov - &lt;a href=&quot;mailto:lazy.kent@opensuse.org&quot;&gt;lazy.kent@opensuse.org&lt;/a&gt;, ViktorOn - &lt;a href=&quot;https://github.com/ViktorOn&quot;&gt;ViktorOn&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="239"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Swedish translation: &lt;/span&gt;Åke Engelbrektson - &lt;a href=&quot;mailto:eson@svenskasprakfiler.se&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;eson@svenskasprakfiler.se&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="262"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;If you appreciate this work and would like to support the project, you are welcome to donate via PayPal&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="322"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;Follow Converseen:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;Sigue a Converseen:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="402"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../src/dialoginfo.cpp" line="38"/>
        <source>ImageMagick Version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dialoginfo.cpp" line="51"/>
        <source>The batch image converter and resizer.</source>
        <translation>Convierte y redimensiona imágenes por lotes.</translation>
    </message>
</context>
<context>
    <name>DialogMultipageEditor</name>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="14"/>
        <source>Import multipage document</source>
        <translation>Importar documento multipágina</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="20"/>
        <source>Check the pages or subimages you want to import</source>
        <translation>Marca las páginas o subimágenes que quieres importar</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="42"/>
        <source>Page</source>
        <translation>Página</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="47"/>
        <source>Pixel size</source>
        <translation>Tamaño de píxel</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="52"/>
        <source>Density</source>
        <translation>Densidad</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="57"/>
        <source>Depth</source>
        <translation>Profundidad</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="65"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://converseen.fasterland.net/converseen-can-convert-pdf-as-image-files/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;How to enable the PDF conversion?&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="93"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="104"/>
        <source>Import</source>
        <translation>Importar</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="121"/>
        <source>Check</source>
        <translation>Marcar</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="130"/>
        <source>Check all</source>
        <translation>Marcar todas</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="139"/>
        <source>Uncheck</source>
        <translation>Desmarcar</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="148"/>
        <source>Uncheck all</source>
        <translation>Desmarcar todas</translation>
    </message>
</context>
<context>
    <name>DialogOptions</name>
    <message>
        <location filename="../ui/dialogoptions.ui" line="14"/>
        <source>Settings</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="20"/>
        <source>Language</source>
        <translation>Idioma</translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="26"/>
        <source>Language:</source>
        <translation>Idioma:</translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="46"/>
        <source>Overwriting settings</source>
        <translation>Al sobreescribir</translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="52"/>
        <source>As&amp;k first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="62"/>
        <source>O&amp;verwrite all existing images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="72"/>
        <source>Updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="78"/>
        <source>Checks for updates automatically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="103"/>
        <source>Ok</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="110"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/dialogoptions.cpp" line="61"/>
        <source>Warning!</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <location filename="../src/dialogoptions.cpp" line="62"/>
        <source>Please, restart Converseen to apply current language!</source>
        <translation>Reinicia Converseen para aplicar el nuevo idioma.</translation>
    </message>
</context>
<context>
    <name>DialogQuality</name>
    <message>
        <location filename="../ui/dialogquality.ui" line="14"/>
        <source>Image settings</source>
        <translation>Preferencias de imagen</translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="20"/>
        <source>Jpeg compression level</source>
        <translation>Nivel de compresión JPEG</translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="28"/>
        <source>Quality 1 - 100:</source>
        <translation type="unfinished">Calidad 0 - 100: {1 ?} {100:?}</translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="35"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;For the JPEG image formats, quality is 1 (lowest image quality and highest compression) to 100 (best quality but least effective compression).&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="38"/>
        <location filename="../ui/dialogquality.ui" line="117"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;#&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4; vertical-align:super;&quot;&gt;?&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="99"/>
        <source>Png/Mng compression level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="107"/>
        <source>Quality 0 - 9:</source>
        <translation type="unfinished">Calidad 0 - 100: {0 ?} {9:?}</translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="114"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Sets the zlib compression level from 1 to 9 (1 is lowest and 9 is highest).&lt;/p&gt;&lt;p&gt;For compression level 0, the Huffman-only strategy is used, which is fastest but not necessarily the worst compression.&lt;/p&gt;&lt;p&gt;PNG uses a &apos;lossless&apos; compression method, so increasing the compression does NOT reduce your image quality.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="172"/>
        <source>Interpolation</source>
        <translation>Interpolación</translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="180"/>
        <source>Filter:</source>
        <translation>Filtro:</translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="223"/>
        <source>Ok</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="230"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>DialogShowUpdateMsg</name>
    <message>
        <location filename="../ui/dialogshowupdatemsg.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogshowupdatemsg.ui" line="20"/>
        <source>TextLabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogshowupdatemsg.ui" line="40"/>
        <source>Don&apos;t show again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogshowupdatemsg.ui" line="62"/>
        <source>Update Now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogshowupdatemsg.ui" line="69"/>
        <source>Not Now</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Formats</name>
    <message>
        <location filename="../src/formats.cpp" line="94"/>
        <source>All Supported Filters (%1)</source>
        <translation>Todos los filtros soportados (%1)</translation>
    </message>
    <message>
        <location filename="../src/formats.cpp" line="121"/>
        <source>Don&apos;t change the format</source>
        <translation>Mantener el formato</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../ui/mainwindow.ui" line="32"/>
        <source>Converseen</source>
        <translation>Converseen</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="67"/>
        <source>Conversion Formats</source>
        <translation>Formatos de conversión</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="75"/>
        <source>Convert to:</source>
        <translation>Convertir a:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="109"/>
        <source>Show image settings dialog...</source>
        <translation>Mostrar diálogo de preferencias de imagen...</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="112"/>
        <source>Images settings</source>
        <translation>Preferencias de imagen</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="174"/>
        <source>&amp;File</source>
        <translation>Archivo</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="179"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="184"/>
        <source>&amp;Actions</source>
        <translation>&amp;Acciones</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="189"/>
        <source>&amp;Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="260"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Preview:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Vista previa:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="368"/>
        <source>Show preview</source>
        <translation>Mostrar vista previa</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="422"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;right&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#828282;&quot;&gt;Type:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;right&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#828282;&quot;&gt;Tipo:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="433"/>
        <location filename="../ui/mainwindow.ui" line="459"/>
        <location filename="../ui/mainwindow.ui" line="485"/>
        <location filename="../ui/mainwindow.ui" line="511"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt; - &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt; - &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="448"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;right&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#828282;&quot;&gt;File size:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;right&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#828282;&quot;&gt;Tamaño del archivo:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="474"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;right&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#828282;&quot;&gt;Image size:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;right&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#828282;&quot;&gt;Tamaño de la imagen:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="500"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;right&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#828282;&quot;&gt;Image resolution:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;right&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#828282;&quot;&gt;Resolución de la imagen:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="536"/>
        <source>Dimensions</source>
        <translation>Dimensiones</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="570"/>
        <source>Width:</source>
        <translation>Ancho:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="577"/>
        <source>Height:</source>
        <translation>Altura:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="664"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;0 x 0 pixel&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;0 x 0 pixel&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="684"/>
        <source>Mantain aspect ratio</source>
        <translation>Mantener relación de aspecto</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="143"/>
        <source>Replace transparent background</source>
        <translation>Reemplazar el fondo transparente</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="150"/>
        <source>Choose color</source>
        <translation>Seleccionar color</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="220"/>
        <source>Actio&amp;ns Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="554"/>
        <source>Scale image</source>
        <translation>Escalar imagen</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="677"/>
        <source>Link aspect with selected image</source>
        <translation>Relacionar aspecto con imagen seleccionada</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="705"/>
        <source>Resolution</source>
        <translation>Resolución</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="721"/>
        <source>Resolution X:</source>
        <translation>Resolución X:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="728"/>
        <source>Resolution Y:</source>
        <translation>Resolución Y:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="767"/>
        <location filename="../ui/mainwindow.ui" line="773"/>
        <source>Rotate and flip</source>
        <translation>Rotar e invertir</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="788"/>
        <source>Rotate image:</source>
        <translation>Rotar imagen:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="797"/>
        <source>No rotation</source>
        <translation>No rotar</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="869"/>
        <source>Flip image:</source>
        <translation>Invertir imagen:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="878"/>
        <source>No flip</source>
        <translation>No invertir</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="896"/>
        <source>Horizontally</source>
        <translation>Horizontalmente</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="910"/>
        <source>Vertically</source>
        <translation>Verticalmente</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="960"/>
        <source>Output options</source>
        <translation>Opciones de salida</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="972"/>
        <source>Save in:</source>
        <translation>Guardar en:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="984"/>
        <source>Open output directory</source>
        <translation>Abrir carpeta de destino</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="987"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="998"/>
        <source>Image&apos;s directory</source>
        <translation>Carpeta de la imagen</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1027"/>
        <source>Rename:</source>
        <translation>Renombrar:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1036"/>
        <source>Prefi&amp;x/Suffix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1046"/>
        <source>Progressi&amp;ve Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1063"/>
        <source>#_copy</source>
        <translation>#_copiar</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1070"/>
        <source>Start with:</source>
        <translation>Comenzar con:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1099"/>
        <source>Overwrite all</source>
        <translation>Sobreescribir todo</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1128"/>
        <source>toolBar</source>
        <translation>Barra de herramientas</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1159"/>
        <source>&amp;Open images</source>
        <translation>Abrir imágenes</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1162"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1171"/>
        <source>&amp;Add images</source>
        <translation>&amp;Añadir imágenes</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1174"/>
        <source>Ctrl+Alt+O</source>
        <translation>Ctrl+Alt+O</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1183"/>
        <source>&amp;Remove images</source>
        <translation>Quita&amp;r imágenes</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1186"/>
        <source>Remove selected pictures</source>
        <translation>Quitar imágenes seleccionadas</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1189"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1198"/>
        <source>Remove &amp;all</source>
        <translation>Quit&amp;ar todas</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1201"/>
        <source>Remove all pictures</source>
        <translation>Quitar todas las imágenes</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1204"/>
        <source>Alt+Del</source>
        <translation>Alt+Del</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1213"/>
        <source>&amp;Check</source>
        <translation>Mar&amp;car</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1216"/>
        <source>Check selected items</source>
        <translation>Marcar las seleccionadas</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1219"/>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1228"/>
        <source>Check a&amp;ll</source>
        <translation>Marcar todas</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1231"/>
        <source>Check all items</source>
        <translation>Marcar todas</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1234"/>
        <source>Ctrl+Alt+H</source>
        <translation>Ctrl+Alt+H</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1243"/>
        <source>&amp;Convert</source>
        <translation>&amp;Convertir</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1246"/>
        <source>Start the conversion process</source>
        <translation>Iniciar la conversión</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1249"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1254"/>
        <source>&amp;Settings</source>
        <translation>Preferencia&amp;s</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1257"/>
        <source>Open the settings dialog</source>
        <translation>Abrir el diálogo de preferencias</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1262"/>
        <source>&amp;Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1265"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1270"/>
        <source>Uncheck all &amp;items</source>
        <translation>Desmarcar todas</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1273"/>
        <source>Ctrl+Alt+J</source>
        <translation>Ctrl+Alt+J</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1278"/>
        <source>&amp;Uncheck Items</source>
        <translation>Desmarcar</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1281"/>
        <source>Uncheck selected items</source>
        <translation>Desmarcar las seleccionadas</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1284"/>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1289"/>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1292"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1301"/>
        <source>&amp;Donate via Paypal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1304"/>
        <source>Donate via Paypal</source>
        <translation>Donar mediante PayPal</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1309"/>
        <source>&amp;Report bug...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1327"/>
        <source>&amp;Check for updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1330"/>
        <source>Check if a new version of Converseen is available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1314"/>
        <source>Import PDF file</source>
        <translation>Importar archivo PDF</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="814"/>
        <source>+ &amp;90°</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="828"/>
        <source>- 9&amp;0°</source>
        <translation type="unfinished">- 90° {9&amp;0°?}</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="844"/>
        <source>&amp;180°</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1319"/>
        <source>Import windows icon (*.ico)</source>
        <translation>Importar ícono de Windows (*.ico)</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1322"/>
        <source>Import windows icon (*.ico *.icon)</source>
        <translation>Importar ícono de Windows (*.ico *.icon)</translation>
    </message>
</context>
<context>
    <name>MainWindowImpl</name>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="224"/>
        <source>Open Image</source>
        <translation>Abrir imagen</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="236"/>
        <source>Open Icon file</source>
        <translation>Abrir archivo de ícono</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="236"/>
        <source>Microsoft icon (*.ico *.icon)</source>
        <translation>Ícono de Microsoft (*.ico *.icon)</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="247"/>
        <source>Open Pdf file</source>
        <translation>Abrir archivo PDF</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="247"/>
        <source>Portable Document Format (*.pdf)</source>
        <translation>Portable Document Format (*.pdf)</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="257"/>
        <source>Analyzing the file. It may take a while, please wait...</source>
        <translation>Analizando el archivo. Podría tardar un momento.</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="321"/>
        <location filename="../src/mainwindowimpl.cpp" line="327"/>
        <location filename="../src/mainwindowimpl.cpp" line="336"/>
        <location filename="../src/mainwindowimpl.cpp" line="340"/>
        <location filename="../src/mainwindowimpl.cpp" line="344"/>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="322"/>
        <source>The output directory doesn&apos;t exists! Would you create it?</source>
        <translation>La carpeta de destino no existe. ¿Deseas crearla?</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="328"/>
        <source>The directory cannot be created!</source>
        <translation>No es posible crear la carpeta.</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="337"/>
        <source>Set an output directory!</source>
        <translation>Selecciona una carpeta de destino.</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="341"/>
        <source>No image checked!</source>
        <translation>No hay imágenes marcadas.</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="345"/>
        <source>No images to convert!</source>
        <translation>No hay imágenes para convertir.</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="354"/>
        <source>Processing...</source>
        <translation>Procesando...</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="524"/>
        <source>Processing finished!</source>
        <translation>Proceso terminado.</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="816"/>
        <location filename="../src/mainwindowimpl.cpp" line="874"/>
        <source>Preview</source>
        <translation>Vista previa</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="578"/>
        <source>Open Directory</source>
        <translation>Abrir carpeta</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="947"/>
        <source>Suggest a new name!</source>
        <translation>Sugiere un nuevo nombre.</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="948"/>
        <source>New name:</source>
        <translation>Nuevo nombre:</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="953"/>
        <source>Please, specify a name!</source>
        <translation>Por favor, especifica un nombre.</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="954"/>
        <source>You should specify a name.
Click Retry to specify a new name.
Click Ignore to cancel this operation.
Click Abort to cancel all operations.</source>
        <translation>Deberías especificar un nombre.
Haz clic en Reintentar para especificar un nuevo nombre.
Haz clic en Ignorar para cancelar esta operación.
Haz clic en Abortar para cancelar todas las operaciones.</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="969"/>
        <location filename="../src/mainwindowimpl.cpp" line="974"/>
        <source>Warning!</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="970"/>
        <source>The filename should not be empty!</source>
        <translation>El nombre de archivo no debería estar vacío.</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="975"/>
        <source>The name chosen is identical to the initial one. Do you want to overwrite the original file?</source>
        <translation>El nombre escogido es idéntico al original. ¿Deseas sobreescribir el archivo original?</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="991"/>
        <source>Aborted!</source>
        <translation>Abortado</translation>
    </message>
</context>
<context>
    <name>PixTreeWidget</name>
    <message>
        <location filename="../src/pixtreewidget.cpp" line="40"/>
        <source>To convert</source>
        <translation>Convertir</translation>
    </message>
    <message>
        <location filename="../src/pixtreewidget.cpp" line="41"/>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <location filename="../src/pixtreewidget.cpp" line="42"/>
        <source>File name</source>
        <translation>Nombre del archivo</translation>
    </message>
    <message>
        <location filename="../src/pixtreewidget.cpp" line="43"/>
        <source>Image type</source>
        <translation>Tipo de imagen</translation>
    </message>
    <message>
        <location filename="../src/pixtreewidget.cpp" line="44"/>
        <source>File size</source>
        <translation>Tamaño del archivo</translation>
    </message>
    <message>
        <location filename="../src/pixtreewidget.cpp" line="45"/>
        <source>File path</source>
        <translation>Ruta del archivo</translation>
    </message>
</context>
<context>
    <name>Translator</name>
    <message>
        <location filename="../src/translator.cpp" line="118"/>
        <location filename="../src/translator.cpp" line="131"/>
        <source>English</source>
        <translation>Español</translation>
    </message>
</context>
<context>
    <name>UpdateChecker</name>
    <message>
        <location filename="../src/updatechecker.cpp" line="81"/>
        <source>New version is available!</source>
        <translation>¡Hay una nueva versión disponible!</translation>
    </message>
    <message>
        <location filename="../src/updatechecker.cpp" line="82"/>
        <source>A new version of %1 is available!
Would you download it?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>myLabelPreviewer</name>
    <message>
        <location filename="../src/mylabelpreviewer.cpp" line="53"/>
        <source>Preview</source>
        <translation>Vista previa</translation>
    </message>
</context>
</TS>
